Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(358)

Unified Diff: remoting/host/setup/test_util.h

Issue 1830433002: Adding the message writing class used for remote_security_key STDOUT communication. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@messages
Patch Set: Integrating security message changes Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/setup/test_util.h
diff --git a/remoting/host/setup/test_util.h b/remoting/host/setup/test_util.h
index 8a40f5b6b2f409cc762cf7ea51e87d2821e48d7a..8aacaa4ce4d361cd301a3424fda3bbe0e197fad2 100644
--- a/remoting/host/setup/test_util.h
+++ b/remoting/host/setup/test_util.h
@@ -10,10 +10,18 @@
namespace remoting {
// Creates an anonymous, unidirectional pipe, returning true if successful. On
// success, the receives ownership of both files.
bool MakePipe(base::File* read_file,
base::File* write_file);
+// Creates an anonymous, unidirectional pipe, returning true if successful. On
+// success, the receives ownership of both files. Uses |buffer_size_bytes| to
+// define the size of the shared buffer.
+bool MakePipe(base::File* read_file,
+ base::File* write_file,
+ unsigned int buffer_size_bytes);
+
} // namespace remoting
#endif // REMOTING_HOST_SETUP_TEST_UTIL_H_
@@ -10,10 +10,18 @@
namespace remoting {
// Creates an anonymous, unidirectional pipe, returning true if successful. On
-// success, the receives ownership of both files.
+// success, the receives ownership of both files. Uses the default buffer size
+// for the platform.
bool MakePipe(base::File* read_file,
base::File* write_file);

Powered by Google App Engine
This is Rietveld 408576698